@@ -1,9 +1,7 @@
 package File::Listing;
 
-# $Id: Listing.pm,v 1.14 2003/10/23 19:11:32 uid39246 Exp $
-
 sub Version { $VERSION; }
-$VERSION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
+$VERSION = "5.837";
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -116,8 +114,7 @@ package File::Listing::unix;
 use HTTP::Date qw(str2time);
 
 # A place to remember current directory from last line parsed.
-use vars qw($curdir);
-no strict qw(vars);
+use vars qw($curdir @ISA);
 
 @ISA = qw(File::Listing);
 
@@ -144,7 +141,7 @@ sub line
 	 .*                                       # Graps
 	 \D(\d+)                                  # File size
 	 \s+                                      # Some space
-	 (\w{3}\s+\d+\s+(?:\d{1,2}:\d{2}|\d{4}))  # Date
+	 (\w{3}\s+\d+\s+(?:\d{1,2}:\d{2}|\d{4})|\d{4}-\d{2}-\d{2}\s+\d{2}:\d{2})  # Date
 	 \s+                                      # Some more space
 	 (.*)$                                    # File name
 	/x )
@@ -199,6 +196,7 @@ sub line
     }
     else {
         # parse failed, check if the dosftp parse understands it
+        File::Listing::dosftp->init();
         return(File::Listing::dosftp->line($_,$tz,$error));
     }
 
@@ -211,8 +209,7 @@ package File::Listing::dosftp;
 use HTTP::Date qw(str2time);
 
 # A place to remember current directory from last line parsed.
-use vars qw($curdir);
-no strict qw(vars);
+use vars qw($curdir @ISA);
 
 @ISA = qw(File::Listing);
 
@@ -232,11 +229,11 @@ sub line
 
     s/\015//g;
 
-    my ($kind, $size, $date, $name);
+    my ($date, $size_or_dir, $name, $size);
 
     # 02-05-96  10:48AM                 1415 src.slf
     # 09-10-96  09:18AM       <DIR>          sl_util
-    if (($date,$size_or_dir,$name) =
+    if (($date, $size_or_dir, $name) =
         /^(\d\d-\d\d-\d\d\s+\d\d:\d\d\wM)         # Date and time info
          \s+                                      # Some space
          (<\w{3}>|\d+)                            # Dir or Size
@@ -255,9 +252,7 @@ sub line
 	    $type = 'f';
             $size = $size_or_dir;
 	}
-	return [$name, $type, $size, str2time($date, $tz),
-              File::Listing::file_mode($kind)];
-
+	return [$name, $type, $size, str2time($date, $tz), undef];
     }
     else {
 	return () unless defined $error;
@@ -280,6 +275,8 @@ package File::Listing::netware;
 
 package File::Listing::apache;
 
+use vars qw(@ISA);
+
 @ISA = qw(File::Listing);
 
 
@@ -291,9 +288,15 @@ sub line {
     local($_) = shift;
     my($tz, $error) = @_; # ignored for now...
 
-    if (m!<A\s+HREF=\"([^\"]+)\">.*</A>.*?(\d+)-([a-zA-Z]+)-(\d+)\s+(\d+):(\d+)\s+(?:([\d\.]+[kM]?|-))!i) {
+    if (m!<A\s+HREF=\"([^\"]+)\">.*</A>.*?(\d+)-([a-zA-Z]+|\d+)-(\d+)\s+(\d+):(\d+)\s+(?:([\d\.]+[kMG]?|-))!i) {
 	my($filename, $filesize) = ($1, $7);
 	my($d,$m,$y, $H,$M) = ($2,$3,$4,$5,$6);
+	if ($m =~ /^\d+$/) {
+	    ($d,$y) = ($y,$d) # iso date
+	}
+	else {
+	    $m = _monthabbrev_number($m);
+	}
 
 	$filesize = 0 if $filesize eq '-';
 	if ($filesize =~ s/k$//i) {
@@ -308,7 +311,7 @@ sub line {
 	$filesize = int $filesize;
 
 	require Time::Local;
-	my $filetime = Time::Local::timelocal(0,$M,$H,$d,_monthabbrev_number($m)-1,_guess_year($y)-1900);
+	my $filetime = Time::Local::timelocal(0,$M,$H,$d,$m-1,_guess_year($y)-1900);
 	my $filetype = ($filename =~ s|/$|| ? "d" : "f");
 	return [$filename, $filetype, $filesize, $filetime, undef];
     }
@@ -353,11 +356,12 @@ __END__
 
 =head1 NAME
 
-parse_dir - parse directory listing
+File::Listing - parse directory listing
 
 =head1 SYNOPSIS
 
- use File::Listing;
+ use File::Listing qw(parse_dir);
+ $ENV{LANG} = "C";  # dates in non-English locales not supported
  for (parse_dir(`ls -l`)) {
      ($name, $type, $size, $mtime, $mode) = @$_;
      next if $type ne 'f'; # plain file
@@ -370,11 +374,8 @@ parse_dir - parse directory listing
 
 =head1 DESCRIPTION
 
-The parse_dir() routine can be used to parse directory
-listings. Currently it only understand Unix C<'ls -l'> and C<'ls -lR'>
-format.  It should eventually be able to most things you might get
-back from a ftp server file listing (LIST command), i.e. VMS listings,
-NT listings, DOS listings,...
+This module exports a single function called parse_dir(), which can be
+used to parse directory listings.
 
 The first parameter to parse_dir() is the directory listing to parse.
 It can be a scalar, a reference to an array of directory lines or a
@@ -384,10 +385,10 @@ The second parameter is the time zone to use when parsing time stamps
 in the listing. If this value is undefined, then the local time zone is
 assumed.
 
-The third parameter is the type of listing to assume.  The values will
-be strings like 'unix', 'vms', 'dos'.  Currently only 'unix' is
-implemented and this is also the default value.  Ideally, the listing
-type should be determined automatically.
+The third parameter is the type of listing to assume.  Currently
+supported formats are 'unix', 'apache' and 'dosftp'.  The default
+value 'unix'.  Ideally, the listing type should be determined
+automatically.
 
 The fourth parameter specifies how unparseable lines should be treated.
 Values can be 'ignore', 'warn' or a code reference.  Warn means that
