@@ -5,7 +5,7 @@ use HTTP::Date qw(str2time parse_date time2str);
 use HTTP::Headers::Util qw(_split_header_words join_header_words);
 
 use vars qw($VERSION $EPOCH_OFFSET);
-$VERSION = "5.833";
+$VERSION = "5.837";
 
 # Legacy: because "use "HTTP::Cookies" used be the ONLY way
 #  to load the class HTTP::Cookies::Netscape.
@@ -610,7 +610,7 @@ HTTP::Cookies - HTTP cookie jars
 
   use HTTP::Cookies;
   $cookie_jar = HTTP::Cookies->new(
-    file => "$ENV{'HOME'}/lwp_cookies.dat',
+    file => "$ENV{'HOME'}/lwp_cookies.dat",
     autosave => 1,
   );
 
