@@ -4,7 +4,7 @@ use strict;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = "5.810";
+$VERSION = "5.821";
 
 require HTTP::Cookies;
 @ISA=qw(HTTP::Cookies);
@@ -225,7 +225,8 @@ sub load
 			}
 		}
 
-		if ($data =~ /Cookie\:$user_name\@([\x21-\xFF]+).*?($user_name\@[\x21-\xFF]+\.txt)/)
+                (my $user_name2 = $user_name) =~ s/ /_/g;
+		if ($data =~ /Cookie\:\Q$user_name\E\@([\x21-\xFF]+).*?((?:\Q$user_name\E|\Q$user_name2\E)\@[\x21-\xFF]+\.txt)/)
 		{
 			my $cookie_file = $cookie_dir . $2; # form full pathname
 
