@@ -1,6 +1,6 @@
-package HTTP::Date;  # $Date: 2003/10/13 09:15:19 $
+package HTTP::Date;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.45 $ =~ /(\d+)\.(\d+)/);
+$VERSION = "5.831";
 
 require 5.004;
 require Exporter;
@@ -39,14 +39,13 @@ sub str2time ($;$)
     # fast exit for strictly conforming string
     if ($str =~ /^[SMTWF][a-z][a-z], (\d\d) ([JFMAJSOND][a-z][a-z]) (\d\d\d\d) (\d\d):(\d\d):(\d\d) GMT$/) {
 	return eval {
-	    my $t = Time::Local::timegm($6, $5, $4, $1, $MoY{$2}-1, $3-1900);
+	    my $t = Time::Local::timegm($6, $5, $4, $1, $MoY{$2}-1, $3);
 	    $t < 0 ? undef : $t;
 	};
     }
 
     my @d = parse_date($str);
     return undef unless @d;
-    $d[0] -= 1900;  # year
     $d[1]--;        # month
 
     my $tz = pop(@d);
@@ -229,7 +228,8 @@ sub parse_date ($)
 
     if (defined $tz) {
 	$tz = "Z" if $tz =~ /^(GMT|UTC?|[-+]?0+)$/;
-    } else {
+    }
+    else {
 	$tz = "";
     }
     return sprintf("%04d-%02d-%02d %02d:%02d:%02d%s",
@@ -283,8 +283,8 @@ time2str() and str2time(), are exported by default.
 =item time2str( [$time] )
 
 The time2str() function converts a machine time (seconds since epoch)
-to a string.  If the function is called without an argument, it will
-use the current time.
+to a string.  If the function is called without an argument or with an
+undefined argument, it will use the current time.
 
 The string returned is in the format preferred for the HTTP protocol.
 This is a fixed length subset of the format defined by RFC 1123,
@@ -296,9 +296,10 @@ in this format is:
 =item str2time( $str [, $zone] )
 
 The str2time() function converts a string to machine time.  It returns
-C<undef> if the format of $str is unrecognized, or the time is outside
-the representable range.  The time formats recognized are the same as
-for parse_date().
+C<undef> if the format of $str is unrecognized, otherwise whatever the
+C<Time::Local> functions can make out of the parsed time.  Dates
+before the system's epoch may not work on all operating systems.  The
+time formats recognized are the same as for parse_date().
 
 The function also takes an optional second argument that specifies the
 default time zone to use when converting the date.  This parameter is
