@@ -4,7 +4,7 @@ use strict;
 use Carp ();
 
 use vars qw($VERSION $TRANSLATE_UNDERSCORE);
-$VERSION = "5.818";
+$VERSION = "5.835";
 
 # The $TRANSLATE_UNDERSCORE variable controls whether '_' can be used
 # as a replacement for '-' in header field names.
@@ -199,16 +199,16 @@ sub _header
 sub _sorted_field_names
 {
     my $self = shift;
-    return sort {
+    return [ sort {
         ($header_order{$a} || 999) <=> ($header_order{$b} || 999) ||
          $a cmp $b
-    } keys %$self
+    } keys %$self ];
 }
 
 
 sub header_field_names {
     my $self = shift;
-    return map $standard_case{$_} || $_, $self->_sorted_field_names
+    return map $standard_case{$_} || $_, @{ $self->_sorted_field_names },
 	if wantarray;
     return keys %$self;
 }
@@ -218,17 +218,17 @@ sub scan
 {
     my($self, $sub) = @_;
     my $key;
-    foreach $key ($self->_sorted_field_names) {
-        next if $key =~ /^_/;
+    for $key (@{ $self->_sorted_field_names }) {
+	next if substr($key, 0, 1) eq '_';
 	my $vals = $self->{$key};
 	if (ref($vals) eq 'ARRAY') {
 	    my $val;
 	    for $val (@$vals) {
-		&$sub($standard_case{$key} || $key, $val);
+		$sub->($standard_case{$key} || $key, $val);
 	    }
 	}
 	else {
-	    &$sub($standard_case{$key} || $key, $vals);
+	    $sub->($standard_case{$key} || $key, $vals);
 	}
     }
 }
@@ -240,29 +240,51 @@ sub as_string
     $endl = "\n" unless defined $endl;
 
     my @result = ();
-    $self->scan(sub {
-	my($field, $val) = @_;
-	$field =~ s/^://;
-	if ($val =~ /\n/) {
-	    # must handle header values with embedded newlines with care
-	    $val =~ s/\s+$//;          # trailing newlines and space must go
-	    $val =~ s/\n\n+/\n/g;      # no empty lines
-	    $val =~ s/\n([^\040\t])/\n $1/g;  # intial space for continuation
-	    $val =~ s/\n/$endl/g;      # substitute with requested line ending
+    for my $key (@{ $self->_sorted_field_names }) {
+	next if index($key, '_') == 0;
+	my $vals = $self->{$key};
+	if ( ref($vals) eq 'ARRAY' ) {
+	    for my $val (@$vals) {
+		my $field = $standard_case{$key} || $key;
+		$field =~ s/^://;
+		if ( index($val, "\n") >= 0 ) {
+		    $val = _process_newline($val, $endl);
+		}
+		push @result, $field . ': ' . $val;
+	    }
 	}
-	push(@result, "$field: $val");
-    });
+	else {
+	    my $field = $standard_case{$key} || $key;
+	    $field =~ s/^://;
+	    if ( index($vals, "\n") >= 0 ) {
+		$vals = _process_newline($vals, $endl);
+	    }
+	    push @result, $field . ': ' . $vals;
+	}
+    }
 
     join($endl, @result, '');
 }
 
+sub _process_newline {
+    local $_ = shift;
+    my $endl = shift;
+    # must handle header values with embedded newlines with care
+    s/\s+$//;        # trailing newlines and space must go
+    s/\n(\x0d?\n)+/\n/g;     # no empty lines
+    s/\n([^\040\t])/\n $1/g; # intial space for continuation
+    s/\n/$endl/g;    # substitute with requested line ending
+    $_;
+}
+
+
 
 if (eval { require Storable; 1 }) {
     *clone = \&Storable::dclone;
 } else {
     *clone = sub {
 	my $self = shift;
-	my $clone = new HTTP::Headers;
+	my $clone = HTTP::Headers->new;
 	$self->scan(sub { $clone->push_header(@_);} );
 	$clone;
     };
@@ -313,6 +335,37 @@ sub content_type      {
     wantarray ? @ct : $ct[0];
 }
 
+sub content_type_charset {
+    my $self = shift;
+    require HTTP::Headers::Util;
+    my $h = $self->{'content-type'};
+    $h = $h->[0] if ref($h);
+    $h = "" unless defined $h;
+    my @v = HTTP::Headers::Util::split_header_words($h);
+    if (@v) {
+	my($ct, undef, %ct_param) = @{$v[0]};
+	my $charset = $ct_param{charset};
+	if ($ct) {
+	    $ct = lc($ct);
+	    $ct =~ s/\s+//;
+	}
+	if ($charset) {
+	    $charset = uc($charset);
+	    $charset =~ s/^\s+//;  $charset =~ s/\s+\z//;
+	    undef($charset) if $charset eq "";
+	}
+	return $ct, $charset if wantarray;
+	return $charset;
+    }
+    return undef, undef if wantarray;
+    return undef;
+}
+
+sub content_is_text {
+    my $self = shift;
+    return $self->content_type =~ m,^text/,;
+}
+
 sub content_is_html {
     my $self = shift;
     return $self->content_type eq 'text/html' || $self->content_is_xhtml;
@@ -521,9 +574,9 @@ possible to tell which of the returned values belonged to which field.
 =item $h->remove_content_headers
 
 This will remove all the header fields used to describe the content of
-a message.  All header field names prefixed with C<Content-> falls
+a message.  All header field names prefixed with C<Content-> fall
 into this category, as well as C<Allow>, C<Expires> and
-C<Last-Modified>.  RFC 2616 denote these fields as I<Entity Header
+C<Last-Modified>.  RFC 2616 denotes these fields as I<Entity Header
 Fields>.
 
 The return value is a new C<HTTP::Headers> object that contains the
@@ -573,7 +626,7 @@ values will be substituted with this line ending sequence.
 =head1 CONVENIENCE METHODS
 
 The most frequently used headers can also be accessed through the
-following convenience Methods.  Most of these methods can both be used to read
+following convenience methods.  Most of these methods can both be used to read
 and to set the value of a header.  The header value is set if you pass
 an argument to the method.  The old header value is always returned.
 If the given header did not exist then C<undef> is returned.
@@ -635,6 +688,17 @@ string is returned.  This makes it safe to do the following:
      ...
   }
 
+=item $h->content_type_charset
+
+Returns the upper-cased charset specified in the Content-Type header.  In list
+context return the lower-cased bare content type followed by the upper-cased
+charset.  Both values will be C<undef> if not specified in the header.
+
+=item $h->content_is_text
+
+Returns TRUE if the Content-Type header field indicate that the
+content is textual.
+
 =item $h->content_is_html
 
 Returns TRUE if the Content-Type header field indicate that the
@@ -680,7 +744,7 @@ standard.>
 This header field is used in request messages and contains information
 about the user agent originating the request.  I<E.g.>:
 
-  $h->user_agent('Mozilla/1.2');
+  $h->user_agent('Mozilla/5.0 (compatible; MSIE 7.0; Windows NT 6.0)');
 
 =item $h->server
 
