@@ -1,6 +1,6 @@
 package HTTP::Negotiate;
 
-$VERSION = "5.813";
+$VERSION = "5.835";
 sub Version { $VERSION; }
 
 require 5.002;
@@ -19,7 +19,7 @@ sub choose ($;$)
 
     unless (defined $request) {
 	# Create a request object from the CGI environment variables
-	$request = new HTTP::Headers;
+	$request = HTTP::Headers->new;
 	$request->header('Accept', $ENV{HTTP_ACCEPT})
 	  if $ENV{HTTP_ACCEPT};
 	$request->header('Accept-Charset', $ENV{HTTP_ACCEPT_CHARSET})
