@@ -5,7 +5,7 @@ use vars qw(@ISA $VERSION);
 
 require LWP::MemberMixin;
 @ISA = qw(LWP::MemberMixin);
-$VERSION = "5.833";
+$VERSION = "5.835";
 
 use HTTP::Request ();
 use HTTP::Response ();
@@ -40,6 +40,7 @@ sub new
     my $def_headers = delete $cnf{default_headers};
     my $timeout = delete $cnf{timeout};
     $timeout = 3*60 unless defined $timeout;
+    my $local_address = delete $cnf{local_address};
     my $use_eval = delete $cnf{use_eval};
     $use_eval = 1 unless defined $use_eval;
     my $parse_head = delete $cnf{parse_head};
@@ -81,6 +82,7 @@ sub new
     my $self = bless {
 		      def_headers  => $def_headers,
 		      timeout      => $timeout,
+		      local_address => $local_address,
 		      use_eval     => $use_eval,
                       show_progress=> $show_progress,
 		      max_size     => $max_size,
@@ -575,6 +577,7 @@ sub get_basic_credentials
 
 
 sub timeout      { shift->_elem('timeout',      @_); }
+sub local_address{ shift->_elem('local_address',@_); }
 sub max_size     { shift->_elem('max_size',     @_); }
 sub max_redirect { shift->_elem('max_redirect', @_); }
 sub show_progress{ shift->_elem('show_progress', @_); }
@@ -639,6 +642,8 @@ sub default_headers {
     my $self = shift;
     my $old = $self->{def_headers} ||= HTTP::Headers->new;
     if (@_) {
+	Carp::croak("default_headers not set to HTTP::Headers compatible object")
+	    unless @_ == 1 && $_[0]->can("header_field_names");
 	$self->{def_headers} = shift;
     }
     return $old;
@@ -1034,6 +1039,7 @@ The following options correspond to attribute methods described below:
    conn_cache              undef
    cookie_jar              undef
    default_headers         HTTP::Headers->new
+   local_address           undef
    max_size                undef
    max_redirect            7
    parse_head              1
@@ -1171,6 +1177,14 @@ password will only be passed to this server.  Example:
 
   $ua->credentials("www.example.com:80", "Some Realm", "foo", "secret");
 
+=item $ua->local_address
+
+=item $ua->local_address( $address )
+
+Get/set the local interface to bind to for network connections.  The interface
+can be specified as a hostname or an IP address.  This value is passed as the
+C<LocalAddr> argument to L<IO::Socket::INET>.
+
 =item $ua->max_size
 
 =item $ua->max_size( $bytes )
@@ -1379,8 +1393,7 @@ handlers for data and might croak to abort the request.
 The handler might set the $response->{default_add_content} value to
 control if any received data should be added to the response object
 directly.  This will initially be false if the $ua->request() method
-was called with a ':content_filename' or ':content_callbak' argument;
-otherwise true.
+was called with a $content_file or $content_cb argument; otherwise true.
 
 =item response_data => sub { my($response, $ua, $h, $data) = @_; ... }
 
@@ -1420,7 +1433,7 @@ The removed handlers are returned.
 =item $ua->set_my_handler( $phase, $cb, %matchspec )
 
 Set handlers private to the executing subroutine.  Works by defaulting
-an C<owner> field to the %matchhspec that holds the name of the called
+an C<owner> field to the %matchspec that holds the name of the called
 subroutine.  You might pass an explicit C<owner> to override this.
 
 If $cb is passed as C<undef>, remove the handler.
