@@ -1,15 +1,14 @@
 package Net::HTTP::NB;
 
-# $Id: NB.pm,v 1.4 2001/05/02 04:40:41 gisle Exp $
-
 use strict;
 use vars qw($VERSION @ISA);
 
-$VERSION = "0.02";
+$VERSION = "5.810";
+
 require Net::HTTP;
 @ISA=qw(Net::HTTP);
 
-sub xread {
+sub sysread {
     my $self = $_[0];
     if (${*$self}{'httpnb_read_count'}++) {
 	${*$self}{'http_buf'} = ${*$self}{'httpnb_save'};
@@ -59,7 +58,7 @@ Net::HTTP::NB - Non-blocking HTTP client
 =head1 SYNOPSIS
 
  use Net::HTTP::NB;
- my $s = Net::HTTP::NB->new(Host => "www.perl.com) || die $@;
+ my $s = Net::HTTP::NB->new(Host => "www.perl.com") || die $@;
  $s->write_request(GET => "/");
 
  use IO::Select;
