@@ -1,14 +1,15 @@
 package Net::HTTPS;
 
-# $Id: HTTPS.pm,v 1.4 2007/07/19 20:26:11 gisle Exp $
-
 use strict;
 use vars qw($VERSION $SSL_SOCKET_CLASS @ISA);
 
-$VERSION = "1.00";
+$VERSION = "5.819";
 
 # Figure out which SSL implementation to use
-if ($Net::SSL::VERSION) {
+if ($SSL_SOCKET_CLASS) {
+    # somebody already set it
+}
+elsif ($Net::SSL::VERSION) {
     $SSL_SOCKET_CLASS = "Net::SSL";
 }
 elsif ($IO::Socket::SSL::VERSION) {
