@@ -1,9 +1,8 @@
-# $Id: AnyDBM_File.pm,v 1.8 1997/12/02 13:27:43 aas Exp $
-
 package WWW::RobotRules::AnyDBM_File;
 
 require  WWW::RobotRules;
 @ISA = qw(WWW::RobotRules);
+$VERSION = "5.835";
 
 use Carp ();
 use AnyDBM_File;
@@ -20,8 +19,8 @@ WWW::RobotRules::AnyDBM_File - Persistent RobotRules
  require LWP::RobotUA;
 
  # Create a robot useragent that uses a diskcaching RobotRules
- my $rules = new WWW::RobotRules::AnyDBM_File 'my-robot/1.0', 'cachefile';
- my $ua = new WWW::RobotUA 'my-robot/1.0', 'me@foo.com', $rules;
+ my $rules = WWW::RobotRules::AnyDBM_File->new( 'my-robot/1.0', 'cachefile' );
+ my $ua = WWW::RobotUA->new( 'my-robot/1.0', 'me@foo.com', $rules );
 
  # Then just use $ua as usual
  $res = $ua->request($req);
@@ -51,7 +50,8 @@ sub new
   
   if ($ua) {
       $self->agent($ua);
-  } else {
+  }
+  else {
       # Try to obtain name from DBM file
       $ua = $self->{'dbm'}{"|ua-name|"};
       Carp::croak("No agent name specified") unless $ua;
@@ -70,6 +70,7 @@ sub agent {
 	    my $file = $self->{'filename'};
 	    untie %{$self->{'dbm'}};
 	    tie %{$self->{'dbm'}}, 'AnyDBM_File', $file, O_TRUNC|O_RDWR, 0640;
+	    %{$self->{'dbm'}} = ();
 	    $self->{'dbm'}{"|ua-name|"} = $newname;
 	}
     }
